==> 1.1.1_20241022_release_inc.zip: app/service/admin/S_category.php <==
<?php

namespace app\service\admin;

use app\db\admin\D_category;

class S_category
{
    public $d_category;

    public function __construct()
    {
        $this->d_category = new D_category();
    }

    /**
     * 获取数据
     * @param string $paramObj
     * @return array
     */
    public function getData($paramObj=""){
        return $this->d_category->getData($paramObj);
    }

    /**
     * 更新 单条-linkurl 数据
     * @param string $paramObj
     * @return array
     */
    public function updateRowLinkurl($paramObj=""){
        return $this->d_category->updateRowLinkurl($paramObj);
    }

    /**
     * 获取父级数据
     * @param string $paramObj
     * @return array
     */
    public function getParentData($paramObj=""){
        return $this->d_category->getParentData($paramObj);
    }

    /**
     * 获取子级数据
     * @param string $paramObj
     * @return array
     */
    public function getChildData($paramObj=""){
        return $this->d_category->getChildData($paramObj);
    }

    /**
     * 更新 linkurl 数据
     * @param string $paramObj
     * @return array
     */
    public function updateLinkurl($paramObj=""){
        return $this->d_category->updateLinkurl($paramObj);
    }

    /**
     * 获取模块分类
     * @param string $paramObj
     * @return array
     */
    public function getModuleData($paramObj=""){
        return $this->d_category->getModuleData($paramObj);
    }

    /**
     * 文章列表数据
     * @param string $paramObj
     * @return array
     */
    public function listData($paramObj=""){
        return $this->d_category->listData($paramObj);
    }

    /**
     * 获取数据详情
     * @param string $paramObj
     * @return array
     */
    public function info($paramObj=""){
        return $this->d_category->info($paramObj);
    }

    /**
     * 获取子元素数据
     * @param string $paramObj
     * @return array
     */
    public function getChildVal($paramObj=""){
        return $this->d_category->getChildVal($paramObj);
    }

    /**
     * 获取父级元素数据
     * @param string $paramObj
     * @return array
     */
    public function getParentVal($paramObj=""){
        return $this->d_category->getParentVal($paramObj);
    }

    /**
     * 初始化分类数据
     * @param string $paramObj
     * @return array
     */
    public function init($paramObj=""){
        return $this->d_category->init($paramObj);
    }

    /**
     * 所有数据
     * @param string $paramObj
     * @return array
     */
    public function allData($paramObj=""){
        return $this->d_category->allData($paramObj);
    }

    /**
     * 创建数据
     * @param string $paramObj
     * @return array
     */
    public function store($paramObj=""){
        return $this->d_category->store($paramObj);
    }

    /**
     * 更新数据
     * @param string $paramObj
     * @return array
     */
    public function update($paramObj=""){
        return $this->d_category->update($paramObj);
    }

    /**
     * 记录数据
     * @param string $paramObj
     * @return array
     */
    public function record($paramObj=""){
        return $this->d_category->record($paramObj);
    }

    /**
     * 删除数据
     * @param string $paramObj
     * @return array
     */
    public function delete($paramObj=""){
        return $this->d_category->delete($paramObj);
    }

    public function __call($name,$arguments)
    {
        return recordLogMsgLevelTwo(app("errorLevel")::E_WARNING,app("errorCode")::UNDEFINED_METHOD,lang("sys.noMethodDefined"),$name,$arguments);
    }
}

==> 1.1.2_20241102_release_inc.zip: app/service/admin/S_category.php <==
<?php

namespace app\service\admin;

use app\db\admin\D_category;

class S_category
{
    public $d_category;

    public function __construct()
    {
        $this->d_category = new D_category();
    }

    /**
     * 更新 单条-linkurl 数据
     * @param string $paramObj
     * @return array
     */
    public function updateRowLinkurl($paramObj=""){
        return $this->d_category->updateRowLinkurl($paramObj);
    }

    /**
     * 获取父级数据
     * @param string $paramObj
     * @return array
     */
    public function getParentData($paramObj=""){
        return $this->d_category->getParentData($paramObj);
    }

    /**
     * 获取子级数据
     * @param string $paramObj
     * @return array
     */
    public function getChildData($paramObj=""){
        return $this->d_category->getChildData($paramObj);
    }

    /**
     * 更新 linkurl 数据
     * @param string $paramObj
     * @return array
     */
    public function updateLinkurl($paramObj=""){
        return $this->d_category->updateLinkurl($paramObj);
    }

    /**
     * 获取模块分类
     * @param string $paramObj
     * @return array
     */
    public function getModuleData($paramObj=""){
        return $this->d_category->getModuleData($paramObj);
    }

    /**
     * 文章列表数据
     * @param string $paramObj
     * @return array
     */
    public function listData($paramObj=""){
        return $this->d_category->listData($paramObj);
    }

    /**
     * 获取数据详情
     * @param string $paramObj
     * @return array
     */
    public function info($paramObj=""){
        return $this->d_category->info($paramObj);
    }

    /**
     * 获取子元素数据
     * @param string $paramObj
     * @return array
     */
    public function getChildVal($paramObj=""){
        return $this->d_category->getChildVal($paramObj);
    }

    /**
     * 获取父级元素数据
     * @param string $paramObj
     * @return array
     */
    public function getParentVal($paramObj=""){
        return $this->d_category->getParentVal($paramObj);
    }

    /**
     * 初始化分类数据
     * @param string $paramObj
     * @return array
     */
    public function init($paramObj=""){
        return $this->d_category->init($paramObj);
    }

    /**
     * 所有数据
     * @param string $paramObj
     * @return array
     */
    public function allData($paramObj=""){
        return $this->d_category->allData($paramObj);
    }

    /**
     * 检测分类目录
     * @param string $paramObj
     * @return array
     */
    public function checkDir($paramObj=""){
        return $this->d_category->checkDir($paramObj);
    }

    /**
     * 创建数据
     * @param string $paramObj
     * @return array
     */
    public function store($paramObj=""){
        return $this->d_category->store($paramObj);
    }

    /**
     * 更新数据
     * @param string $paramObj
     * @return array
     */
    public function update($paramObj=""){
        return $this->d_category->update($paramObj);
    }

    /**
     * 记录数据
     * @param string $paramObj
     * @return array
     */
    public function record($paramObj=""){
        return $this->d_category->record($paramObj);
    }

    /**
     * 删除数据
     * @param string $paramObj
     * @return array
     */
    public function delete($paramObj=""){
        return $this->d_category->delete($paramObj);
    }

    public function __call($name,$arguments)
    {
        return recordLogMsgLevelTwo(app("errorLevel")::E_WARNING,app("errorCode")::UNDEFINED_METHOD,lang("sys.noMethodDefined"),$name,$arguments);
    }
}
